@@ -442,7 +442,13 @@ class YandexParser(object):
         if is_video_snippet:
             title = unicode(sn.find('.//*[@class="video2__title"]').text_content())
         else:
-            title = unicode(link.text_content())
+            title_div = link.xpath('.//div[contains(@class,"Organic-Title")]') \
+                or link.xpath('.//div[contains(@class,"OrganicTitle-LinkText")]')
+
+            if len(title_div):
+                title = unicode(title_div[0].text_content())
+            else:
+                title = unicode(link.text_content())
 
         return title, url
 
@@ -617,6 +623,10 @@ class YandexParser(object):
             if sn.attrib['data-fast-name'] == 'related_discovery':
                 return True
 
+            # Популярные товары
+            if sn.attrib['data-fast-name'] == 'market_constr':
+                return True
+
             # Факты
             if sn.attrib['data-fast-name'] == 'entity-fact':
                 return True
@@ -633,6 +643,8 @@ class YandexParser(object):
             if sn.attrib['data-fast-name'] == 'stocks':
                 return True
 
+            return True
+
         html = etree.tostring(sn, method='html', encoding='UTF-8')
         if 't-construct-adapter__market' in sn.attrib['class']:
             if re.search(ur'<div class="organic typo typo_text_m typo_line_s">\s*<div class="organic__content-wrapper clearfix">', html, re.I | re.M):
